==> haskell-constraints-0.11.2-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: constraints
version: 0.11.2
id: constraints-0.11.2-88kGqmIOzi4DqJECoxnbEu
key: constraints-0.11.2-88kGqmIOzi4DqJECoxnbEu
license: BSD-2-Clause
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/constraints/
synopsis: Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.
    .
    This package provides a vocabulary for working with them.
category: Constraints
abi: 6b91fa3ccc75ba7ef82f9fa84907945d
exposed: True
exposed-modules:
    Data.Constraint Data.Constraint.Deferrable Data.Constraint.Forall
    Data.Constraint.Lifting Data.Constraint.Nat Data.Constraint.Symbol
    Data.Constraint.Unsafe
import-dirs: /usr/lib/ghc-8.6.5/site-local/constraints-0.11.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/constraints-0.11.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/constraints-0.11.2
hs-libraries: HSconstraints-0.11.2-88kGqmIOzi4DqJECoxnbEu
depends:
    base-4.12.0.0 binary-0.8.6.0 deepseq-1.4.4.0 ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo mtl-2.2.2
    transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    type-equality-1-5A9N6Ts8RtY5wkf4DqaBDT
haddock-interfaces: /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html: /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-0.11-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: constraints
version: 0.11
id: constraints-0.11-1mpDQajVxfT7QBTxc1wX3l
key: constraints-0.11-1mpDQajVxfT7QBTxc1wX3l
license: BSD-2-Clause
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/constraints/
synopsis: Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.
    .
    This package provides a vocabulary for working with them.
category: Constraints
abi: 00c715c93cfe125673caad43752a3ef2
exposed: True
exposed-modules:
    Data.Constraint Data.Constraint.Deferrable Data.Constraint.Forall
    Data.Constraint.Lifting Data.Constraint.Nat Data.Constraint.Symbol
    Data.Constraint.Unsafe
import-dirs: /usr/lib/ghc-8.6.5/site-local/constraints-0.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/constraints-0.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/constraints-0.11
hs-libraries: HSconstraints-0.11-1mpDQajVxfT7QBTxc1wX3l
depends:
    base-4.12.0.0 binary-0.8.6.0 deepseq-1.4.4.0 ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo mtl-2.2.2
    transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html: /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
